@@ -1,6 +1,5 @@
 class NoDataError(Exception):
-    """
-    Error to be raised when pyhis can't extract data from a waterml
+    """Error to be raised when pyhis can't extract data from a waterml
     response (either because the response contains no data or the
     response is invalid)
     """
